@@ -117,7 +117,9 @@ int Parse(Core &C, string &Argument)
     OPTION("--md5-verify",                                  MD5_Verify)
     OPTION("--md5-embed-overwrite",                         MD5_Embed_Overwrite)
     OPTION("--md5-embed",                                   MD5_Embed)
-    
+
+    OPTION("--remove-chunks=",                              Chunks_Remove)
+
     //Default
     OPTION("--",                                            Default)
     OPTION("-",                                             Default)
@@ -776,7 +778,6 @@ CL_OPTION(MD5_Generate)
 //---------------------------------------------------------------------------
 CL_OPTION(MD5_Verify)
 {
-    C.GenerateMD5=true;
     C.VerifyMD5=true;
     C.VerifyMD5_Force=true;
 
@@ -786,7 +787,6 @@ CL_OPTION(MD5_Verify)
 //---------------------------------------------------------------------------
 CL_OPTION(MD5_Embed)
 {
-    C.GenerateMD5=true;
     C.EmbedMD5=true;
 
     return -2; //Continue
@@ -795,13 +795,54 @@ CL_OPTION(MD5_Embed)
 //---------------------------------------------------------------------------
 CL_OPTION(MD5_Embed_Overwrite)
 {
-    C.GenerateMD5=true;
     C.EmbedMD5=true;
     C.EmbedMD5_AuthorizeOverWritting=true;
 
     return -2; //Continue
 }
 
+//***************************************************************************
+// Options - Others
+//***************************************************************************
+
+//---------------------------------------------------------------------------
+CL_OPTION(Chunks_Remove)
+{
+    ZtringList Fields;
+    Fields.Separator_Set(0, __T(","));
+    Fields.Write(Ztring().From_Local(string().assign(Argument, 16, std::string::npos)));
+
+    for (auto Field : Fields)
+    {
+        ZtringList Chunks;
+        Chunks.Separator_Set(0, __T("/"));
+        Chunks.Write(Field);
+
+        size_t Level=0;
+        for (auto Chunk :Chunks)
+        {
+            if (Chunk.empty()) // handle duplicate slashes
+                continue;
+
+            Level++;
+            if (Chunk.size()!=4)
+            {
+                std::cerr<<"Invalid chunk identifier: "<<Chunk.To_UTF8()<<std::endl;
+                return 1;
+            }
+            else if (!Level && (Chunk==__T("data") || Chunk==__T("ds64") || Chunk==__T("fmt ")))
+            {
+                std::cerr<<"Unable to remove mandatory chunk: "<<Chunk.To_UTF8()<<std::endl;
+                return 1;
+            }
+        }
+
+        C.In_Chunk_Remove(Field.To_UTF8());
+    }
+
+    return -2;
+}
+
 //***************************************************************************
 // Options - Default
 //***************************************************************************
@@ -809,6 +850,7 @@ CL_OPTION(MD5_Embed_Overwrite)
 CL_OPTION(Default)
 {
     //Form : --(Field)=(Value)
+    bool Append=false;
     size_t Egal_Pos;
     if (Argument.size()==2)
         Egal_Pos=string::npos;
@@ -820,10 +862,13 @@ CL_OPTION(Default)
         return 1;
     }
 
+    if (Egal_Pos && Argument[Egal_Pos-1]=='+')
+        Append=true;
+
     #ifdef _WIN32
-    Ztring Field(Ztring().From_UTF8(Argument), 2, Egal_Pos-2); Field.MakeLowerCase();
+    Ztring Field(Ztring().From_UTF8(Argument), 2, Egal_Pos-(Append?3:2)); Field.MakeLowerCase();
     #else
-    Ztring Field(Ztring().From_Local(Argument), 2, Egal_Pos-2); Field.MakeLowerCase();
+    Ztring Field(Ztring().From_Local(Argument), 2, Egal_Pos-(Append?3:2)); Field.MakeLowerCase();
     #endif
     if (Field!=__T("description")
      && Field!=__T("originator")
@@ -849,7 +894,10 @@ CL_OPTION(Default)
     }
 
     string Value=string(Argument, Egal_Pos+1, std::string::npos);
-    C.In_Core_Add(Field.To_UTF8(), Value);
+    if (Append)
+        C.In_Core_Append(Field.To_UTF8(), Value);
+    else
+        C.In_Core_Add(Field.To_UTF8(), Value);
 
     return -2; //Continue
 }
