@@ -194,6 +194,7 @@ Core::Core()
     Files_Modified_NotWritten_Count=0;
     Canceled=false;
     SaveMode=false;
+    SaveMode_OneFile=false;
     #ifdef _WIN32
         TCHAR Path[MAX_PATH];
         BOOL Result=SHGetSpecialFolderPath(NULL, Path, CSIDL_APPDATA, true);
@@ -337,6 +338,7 @@ float Core::Menu_File_Open_Files_Finish_Middle ()
             Handler->second.In_cue__XML=In_cue__XML;
             Handler->second.In_cue__FileName=In_cue__FileName;
             Handler->second.In_CSET_Remove=In_CSET_Remove;
+            Handler->second.In_Chunks_Remove= Handler_Default.In_Chunks_Remove;
 
             //Settings - Adding default Core values if the Core value does not exist yet (from --xxx=)
             for (map<string, Ztring>::iterator In_Core_Item=Handler_Default.In_Core.begin(); In_Core_Item!=Handler_Default.In_Core.end(); In_Core_Item++)
@@ -345,7 +347,14 @@ float Core::Menu_File_Open_Files_Finish_Middle ()
                 if (Handler_in_Core_Item==Handler->second.In_Core.end())
                     Handler->second.In_Core[Ztring().From_UTF8(In_Core_Item->first).MakeLowerCase().To_UTF8()]=In_Core_Item->second;
             }
-            
+
+            for (map<string, Ztring>::iterator In_Core_Item=Handler_Default.In_Core_Append.begin(); In_Core_Item!=Handler_Default.In_Core_Append.end(); In_Core_Item++)
+            {
+                map<string, Ztring>::iterator Handler_in_Core_Item=Handler->second.In_Core_Append.find(Ztring().From_UTF8(In_Core_Item->first).MakeLowerCase().To_UTF8());
+                if (Handler_in_Core_Item==Handler->second.In_Core_Append.end())
+                    Handler->second.In_Core_Append[Ztring().From_UTF8(In_Core_Item->first).MakeLowerCase().To_UTF8()]=In_Core_Item->second;
+            }
+
             //Special Characters
             if (SpecialChars_Enabled)
             {
@@ -358,6 +367,16 @@ float Core::Menu_File_Open_Files_Finish_Middle ()
                     Field->second.FindAndReplace(__T("\\0"), __T("\0"), 0, Ztring_Recursive);
                     Field->second.FindAndReplace(__T("|SC1|"), __T("\\"), 0, Ztring_Recursive);
                 }
+
+                for (map<string, Ztring>::iterator Field=Handler->second.In_Core_Append.begin(); Field!=Handler->second.In_Core_Append.end(); Field++)
+                {
+                    Field->second.FindAndReplace(__T("\\\\"), __T("|SC1|"), 0, Ztring_Recursive);
+                    Field->second.FindAndReplace(__T("\\r"), __T("\r"), 0, Ztring_Recursive);
+                    Field->second.FindAndReplace(__T("\\n"), __T("\n"), 0, Ztring_Recursive);
+                    Field->second.FindAndReplace(__T("\\t"), __T("\t"), 0, Ztring_Recursive);
+                    Field->second.FindAndReplace(__T("\\0"), __T("\0"), 0, Ztring_Recursive);
+                    Field->second.FindAndReplace(__T("|SC1|"), __T("\\"), 0, Ztring_Recursive);
+                }
             }
 
             //Reading
@@ -384,14 +403,27 @@ float Core::Menu_File_Open_Files_Finish_Middle ()
 
         bool IsModified_Old=Handler->second.Riff->IsModified_Get();
 
+        for (size_t Pos=0; Pos<Handler->second.In_Chunks_Remove.size(); Pos++)
+        {
+            Handler->second.Riff->Remove_Chunk(Handler->second.In_Chunks_Remove[Pos].To_UTF8());
+            StdAll(Handler);
+        }
+
         //Modifying file with --xxx values
-        if (!Handler->second.In_Core.empty())
+        if (!Handler->second.In_Core.empty() || !Handler->second.In_Core_Append.empty())
         {
             for (map<string, Ztring>::iterator In_Core_Item=Handler->second.In_Core.begin(); In_Core_Item!=Handler->second.In_Core.end(); In_Core_Item++)
             {
                 Handler->second.Riff->Set(In_Core_Item->first, In_Core_Item->second.To_UTF8(), Rules);
                 StdAll(Handler);
             }
+
+            for (map<string, Ztring>::iterator In_Core_Item=Handler->second.In_Core_Append.begin(); In_Core_Item!=Handler->second.In_Core_Append.end(); In_Core_Item++)
+            {
+                string Value=Handler->second.Riff->Get(In_Core_Item->first);
+                Handler->second.Riff->Set(In_Core_Item->first, Value + In_Core_Item->second.To_UTF8(), Rules);
+                StdAll(Handler);
+            }
         }
         else if (Handler->second.In_Core_Remove)
         {
@@ -524,7 +556,7 @@ float Core::Menu_File_Open_Files_Finish_Middle ()
         CriticalSectionLocker CSL(CS);
 
         StdAll(Handler);
-        if (!FileNotValid_Skip)
+        if (!FileNotValid_Skip && !Canceled)
         {
             //We handle it as a normal file
             Handler++;
@@ -562,12 +594,14 @@ size_t Core::Menu_File_Open_Files_Finish_End()
     {
         CS.Enter();
         Canceled=true;
-        Handler->second.Riff->Cancel();
+        if (Handler->second.Riff)
+            Handler->second.Riff->Cancel();
+
+	while(Handler->second.Riff && !Handler->second.Riff->Canceled_Get())
+	    Sleep(20);
         CS.Leave();
-	    while(!IsExited())
-		    Sleep(20);
     }
-        
+
     CriticalSectionLocker CSL(CS);
 
     //In case of cancel
@@ -581,7 +615,6 @@ size_t Core::Menu_File_Open_Files_Finish_End()
                 Handler++;
                 Handlers.erase(Handler_ToDelete);
 
-                CriticalSectionLocker CSL(CS);
                 Menu_File_Open_Files_File_Pos--;
                 Menu_File_Open_Files_File_Total--;
             }
@@ -628,6 +661,14 @@ bool Core::Menu_File_Open_Files_BackToLastSave()
 float Core::Menu_File_Open_State ()
 {
     CriticalSectionLocker CSL(CS);
+    if (SaveMode_OneFile)
+    {
+        if (Handler!=Handlers.end() && Handler->second.Riff)
+            return Handler->second.Riff->Progress_Get();
+
+        return 1.0;
+    }
+
     if (Menu_File_Open_Files_File_Total==0)
         return 1.0; //No file
     float ToReturn=(float)Menu_File_Open_Files_File_Pos;
@@ -861,19 +902,61 @@ size_t Core::Menu_File_Save_File (const string &FileName)
     TimeS.FindAndReplace(__T(":"), __T("-"), 0, Ztring_Recursive);
     TimeS.FindAndReplace(__T(" "), __T("-"), 0, Ztring_Recursive);
     Out_Core_CSV_FileName=ApplicationFolder.To_UTF8()+"/Backup-"+TimeS.To_UTF8()+".csv";
-    Batch_Launch(Handler);
+    bool Simulation_Enabled_Save=Simulation_Enabled;
+    Simulation_Enabled=true;
+    Batch_Launch();
+    Simulation_Enabled=Simulation_Enabled_Save;
     Out_Core_CSV_FileName.clear();
     Batch_IsBackuping=false;
     
     //Running
+    Batch_Begin();
     Batch_Launch(Handler);
+    Batch_Finish();
 
     return 1;
 }
 
+//---------------------------------------------------------------------------
+size_t Core::Menu_File_Save_File_Start (const string &FileName)
+{
+    SaveMode_OneFile=true;
+    if (!Dir::Exists(ApplicationFolder))
+    {
+        Dir::Create(ApplicationFolder);
+        if (!Dir::Exists(ApplicationFolder))
+            return 0;
+    }
+
+    Handler=Handlers.find(FileName);
+
+    if( Handler==Handlers.end())
+        return 0;
+
+    //Backup
+    Batch_IsBackuping=true;
+    time_t Time=time(NULL);
+    Ztring TimeS; TimeS.Date_From_Seconds_1970_Local((int32u)Time);
+    TimeS.FindAndReplace(__T(":"), __T("-"), 0, Ztring_Recursive);
+    TimeS.FindAndReplace(__T(" "), __T("-"), 0, Ztring_Recursive);
+    Out_Core_CSV_FileName=ApplicationFolder.To_UTF8()+"/Backup-"+TimeS.To_UTF8()+".csv";
+    bool Simulation_Enabled_Save=Simulation_Enabled;
+    Simulation_Enabled=true;
+    Batch_Launch();
+    Simulation_Enabled=Simulation_Enabled_Save;
+    Out_Core_CSV_FileName.clear();
+    Batch_IsBackuping=false;
+
+    //Running
+    bool ToReturn=Batch_Launch_Start();
+
+    return ToReturn;
+}
+
 //---------------------------------------------------------------------------
 size_t Core::Menu_File_Save ()
 {
+    SaveMode_OneFile=false;
     if (!Dir::Exists(ApplicationFolder))
     {
         Dir::Create(ApplicationFolder);
@@ -901,6 +984,7 @@ size_t Core::Menu_File_Save ()
 //---------------------------------------------------------------------------
 bool Core::Menu_File_Save_Start ()
 {
+    SaveMode_OneFile=false;
     if (!Dir::Exists(ApplicationFolder))
     {
         Dir::Create(ApplicationFolder);
@@ -955,7 +1039,7 @@ size_t Core::Menu_File_Save_End ()
         Canceled=true;
         Handler->second.Riff->Cancel();
         CS.Leave();
-        while(!IsExited())
+        while(!Handler->second.Riff->Canceled_Get())
             Sleep(20);
     }
 
@@ -1251,7 +1335,13 @@ bool Core::In_Core_Add (const string &FileName, const string &Field, const strin
         return true;
    
     if (File::Exists(Ztring().From_UTF8(FileName)))
+    {
+        map<string, Ztring>::iterator ToErase=Handlers[FileName].In_Core_Append.find(Field);
+        if (ToErase!=Handlers[FileName].In_Core_Append.end())
+            Handlers[FileName].In_Core_Append.erase(ToErase);
+
         Handlers[FileName].In_Core[Field]=Ztring().From_UTF8(Value);
+    }
     else
     {
         //Handling wildcards
@@ -1260,7 +1350,13 @@ bool Core::In_Core_Add (const string &FileName, const string &Field, const strin
             List.push_back(Ztring().From_UTF8(FileName));
 
         for (size_t Pos=0; Pos<List.size(); Pos++)
+        {
+            map<string, Ztring>::iterator ToErase=Handlers[List[Pos].To_UTF8()].In_Core_Append.find(Field);
+            if (ToErase!=Handlers[List[Pos].To_UTF8()].In_Core_Append.end())
+                Handlers[FileName].In_Core_Append.erase(ToErase);
+
             Handlers[List[Pos].To_UTF8()].In_Core[Field]=Ztring().From_UTF8(Value);
+        }
     }
 
     return true;
@@ -1271,12 +1367,67 @@ bool Core::In_Core_Add (const string &Field, const string &Value)
 {
     if (Value=="NOCHANGE")
         return true;
-   
+
+    map<string, Ztring>::iterator ToErase=Handler_Default.In_Core_Append.find(Field);
+    if (ToErase!=Handler_Default.In_Core_Append.end())
+        Handler_Default.In_Core_Append.erase(ToErase);
+
     Handler_Default.In_Core[Field]=Ztring().From_UTF8(Value);
 
     return true;
 }
 
+//---------------------------------------------------------------------------
+bool Core::In_Chunk_Remove(const string &Field)
+{
+    Handler_Default.In_Chunks_Remove.push_back(Ztring().From_UTF8(Field));
+    return true;
+}
+
+//---------------------------------------------------------------------------
+bool Core::In_Core_Append(const string &FileName, const string &Field, const string &Value)
+{
+    if (Value=="NOCHANGE")
+        return true;
+
+    if (File::Exists(Ztring().From_UTF8(FileName)))
+    {
+        map<string, Ztring>::iterator ToErase=Handlers[FileName].In_Core.find(Field);
+        if (ToErase!=Handlers[FileName].In_Core.end())
+            Handlers[FileName].In_Core.erase(ToErase);
+
+        Handlers[FileName].In_Core_Append[Field]=Ztring().From_UTF8(Value);
+    }
+    else
+    {
+        //Handling wildcards
+        ZtringList List=Dir::GetAllFileNames(Ztring().From_UTF8(FileName));
+        if (List.empty())
+            List.push_back(Ztring().From_UTF8(FileName));
+
+        for (size_t Pos=0; Pos<List.size(); Pos++)
+        {
+            map<string, Ztring>::iterator ToErase=Handlers[List[Pos].To_UTF8()].In_Core.find(Field);
+            if (ToErase!=Handlers[List[Pos].To_UTF8()].In_Core.end())
+                Handlers[FileName].In_Core.erase(ToErase);
+            Handlers[List[Pos].To_UTF8()].In_Core_Append[Field]=Ztring().From_UTF8(Value);
+        }
+    }
+
+    return true;
+}
+
+//---------------------------------------------------------------------------
+bool Core::In_Core_Append(const string &Field, const string &Value)
+{
+    map<string, Ztring>::iterator ToErase=Handler_Default.In_Core.find(Field);
+    if (ToErase!=Handler_Default.In_Core.end())
+        Handler_Default.In_Core.erase(ToErase);
+
+    Handler_Default.In_Core_Append[Field]=Ztring().From_UTF8(Value);
+
+    return true;
+}
 //---------------------------------------------------------------------------
 string Core::Out_Core_Read (const string &FileName, const string &Field)
 {
@@ -1663,8 +1814,13 @@ float Core::Batch_Launch_Middle()
     
     CriticalSectionLocker CSL(CS);
 
-    Handler++;
+    if (SaveMode_OneFile)
+    {
+        Handler=Handlers.end();
+        return 1.0;
+    }
 
+    Handler++;
     Menu_File_Open_Files_File_Pos++;
     if (Menu_File_Open_Files_File_Total==0)
         return 1.0;
@@ -1813,12 +1969,6 @@ void Core::Batch_Launch_Core(handlers::iterator &Handler)
     //Core chunk (with a Conformance Point Document)
     if (!Out_Core_CSV_FileName.empty() && (!Batch_IsBackuping || Handler->second.Riff->IsModified_Get())) //If backuping, only if file is modified
     {
-        if (!Out_Core_CSV_File.Create(Ztring().From_UTF8(Out_Core_CSV_FileName)))
-        {
-            StdErr("--out-Core-CSV=file: error during file creation");
-            Out_Core_CSV_File.Close();
-            Out_Core_CSV_FileName.clear();
-        }
         if (!Out_Core_CSV_File.Write(Core+EOL)) //Saving file part
         {
             StdErr("--out-Core-CSV=file: error during file writing");
@@ -2208,7 +2358,7 @@ void Core::StdAll(handlers::iterator &Handler)
     time_t Time=time(NULL);
     Ztring TimeS; TimeS.Date_From_Seconds_1970_Local((int32u)Time);
 
-    if (!Handler->second.Riff->Information.str().empty())
+    if (Handler->second.Riff && !Handler->second.Riff->Information.str().empty())
     {
         Text_stdout<<TimeS.To_UTF8()<<" "<<Handler->second.Riff->Information.str();
         Text_stdall<<TimeS.To_UTF8()<<" "<<Handler->second.Riff->Information.str();
@@ -2223,7 +2373,7 @@ void Core::StdAll(handlers::iterator &Handler)
         }
         Handler->second.Riff->Information.str(string());
     }
-    if (!Handler->second.Riff->Warnings.str().empty())
+    if (Handler->second.Riff && !Handler->second.Riff->Warnings.str().empty())
     {
         Text_stdout<<TimeS.To_UTF8()<<" "<<Handler->second.Riff->Warnings.str();
         Text_stdall<<TimeS.To_UTF8()<<" "<<Handler->second.Riff->Warnings.str();
@@ -2238,7 +2388,7 @@ void Core::StdAll(handlers::iterator &Handler)
         }
         Handler->second.Riff->Warnings.str(string());
     }
-    if (!Handler->second.Riff->Errors.str().empty())
+    if (Handler->second.Riff && !Handler->second.Riff->Errors.str().empty())
     {
         Text_stderr<<TimeS.To_UTF8()<<" "<<Handler->second.Riff->Errors.str();
         Text_stdall<<TimeS.To_UTF8()<<" "<<Handler->second.Riff->Errors.str();
