@@ -438,9 +438,9 @@ void GUI_Main::OnMenu_File_Open_Files()
     }
 
     //Showing
+    Open_Timer_Init(Timer_Open_Files);
     C->Menu_File_Open_Files_Finish_Start();
     C->Menu_File_Open_Files_Finish_Middle_Threaded();
-    Open_Timer_Init(Timer_Open_Files);
 }
 
 //---------------------------------------------------------------------------
@@ -466,9 +466,9 @@ void GUI_Main::OnMenu_File_Open_Directory()
     #endif
 
     //Showing
+    Open_Timer_Init(Timer_Open_Directory);
     C->Menu_File_Open_Files_Finish_Start();
     C->Menu_File_Open_Files_Finish_Middle_Threaded();
-    Open_Timer_Init(Timer_Open_Directory);
 }
 
 //---------------------------------------------------------------------------
@@ -505,16 +505,10 @@ void GUI_Main::OnMenu_File_Save_Files()
 void GUI_Main::OnMenu_File_Save_File(const QString& FileName)
 {
     C->StdOut(string("Saving file ") + FileName.toStdString() + string("..."));
-    C->Menu_File_Save_File(FileName.toStdString());
-    C->StdOut("Saving files, finished");
-    //Showing
-    if (C->Text_stderr_Updated_Get())
-    {
-        Menu_View_Output_stderr->setChecked(true);
-        View_Refresh(View_Output_stderr);
-    }
-    else
-        View_Refresh();
+
+    Open_Timer_Init(Timer_Save);
+    C->Menu_File_Save_File_Start(FileName.toStdString());
+    C->Menu_File_Save_Middle_Threaded();
 }
 
 //---------------------------------------------------------------------------
@@ -524,9 +518,9 @@ void GUI_Main::OnMenu_File_Save_All()
     C->StdOut("Saving files...");
 
     //Showing
+    Open_Timer_Init(Timer_Save);
     C->Menu_File_Save_Start();
     C->Menu_File_Save_Middle_Threaded();
-    Open_Timer_Init(Timer_Save);
 }
 
 //---------------------------------------------------------------------------
@@ -1352,29 +1346,12 @@ void GUI_Main::OnMenu_Options_GenerateMD5(bool)
             case QMessageBox::Yes     : // Yes was clicked
                                         C->GenerateMD5=true;
                                         C->Menu_File_Options_Update();
-                                        C->Menu_File_Open_Files_Finish(); //TODO: progress bar
-                                        if (C->GenerateMD5==false)
-                                        {
-                                            Menu_Fields_CheckBoxes[Group_MD5*options::MaxCount+Option_MD5_Embed]->setChecked(false);
-                                            //OnMenu_Options_EmbedMD5();
-                                        }
-
-                                        //Showing
-                                        if (C->Text_stderr_Updated_Get())
-                                        {
-                                            Menu_View_Output_stderr->setChecked(true);
-                                            View_Refresh(View_Output_stderr);
-                                        }
-                                        else
-                                            View_Refresh();
+                                        Open_Timer_Init(Timer_Open_Files);
+                                        C->Menu_File_Open_Files_Finish_Start();
+                                        C->Menu_File_Open_Files_Finish_Middle_Threaded();
                                         break;
             case QMessageBox::No      : // No was clicked
                                         C->GenerateMD5=true;
-                                        if (C->GenerateMD5==false)
-                                        {
-                                            Menu_Fields_CheckBoxes[Group_MD5*options::MaxCount+Option_MD5_Embed]->setChecked(false);
-                                            //OnMenu_Options_EmbedMD5();
-                                        }
                                         break;
             case QMessageBox::Cancel  : // Cancel was clicked
                                         C->GenerateMD5=false;
@@ -1386,13 +1363,6 @@ void GUI_Main::OnMenu_Options_GenerateMD5(bool)
     else
     {
         C->GenerateMD5=Menu_Fields_CheckBoxes[Group_MD5*options::MaxCount+Option_MD5_Generate]->isChecked();
-        if (C->GenerateMD5==false)
-        {
-            Menu_Fields_CheckBoxes[Group_MD5*options::MaxCount+Option_MD5_Verify]->setChecked(false);
-            //OnMenu_Options_VerifyMD5();
-            Menu_Fields_CheckBoxes[Group_MD5*options::MaxCount+Option_MD5_Embed]->setChecked(false);
-            //OnMenu_Options_EmbedMD5();
-        }
     }
 }
 
@@ -1402,13 +1372,6 @@ void GUI_Main::OnMenu_Options_VerifyMD5(bool)
     C->VerifyMD5=Menu_Fields_CheckBoxes[Group_MD5*options::MaxCount+Option_MD5_Verify]->isChecked();
     if (C->VerifyMD5==true)
     {
-        Menu_Fields_CheckBoxes[Group_MD5*options::MaxCount+Option_MD5_Generate]->setChecked(true);
-        //OnMenu_Options_GenerateMD5();
-        if (!C->GenerateMD5)
-        {
-            Menu_Fields_CheckBoxes[Group_MD5*options::MaxCount+Option_MD5_Verify]->setChecked(false);
-            //OnMenu_Options_VerifyMD5();
-        }
         C->Menu_File_Options_Update();
 
         //Showing
@@ -1430,11 +1393,6 @@ void GUI_Main::OnMenu_Options_EmbedMD5(bool)
     C->EmbedMD5=Menu_Fields_CheckBoxes[Group_MD5*options::MaxCount+Option_MD5_Embed]->isChecked();
     if (C->EmbedMD5==true)
     {
-        Menu_Fields_CheckBoxes[Group_MD5*options::MaxCount+Option_MD5_Generate]->setChecked(true);
-        if (!C->GenerateMD5)
-        {
-            Menu_Fields_CheckBoxes[Group_MD5*options::MaxCount+Option_MD5_Embed]->setChecked(false);
-        }
         C->Menu_File_Options_Update();
         View_Refresh();
     }
