@@ -19,6 +19,7 @@
 #ifdef MACSTORE
 #include "Common/Mac_Helpers.h"
 #include "ZenLib/Dir.h"
+#include "Riff_Base.h"
 #endif
 
 using namespace std;
@@ -242,7 +243,8 @@ void Riff_Base::Read_Internal_ReadAllInBuffer ()
         if (BytesRead==0)
             break; //Read is finished
         Global->CS.Enter();
-        Global->Progress=(float)Global->In.Position_Get()/Global->In.Size_Get();
+        int64u Skipped=Global->data?Global->data->Size:0;
+        Global->Progress=(float)(Global->In.Position_Get()-Skipped)/Global->In.Size_Get();
         if (Global->Canceling)
         {
             Global->CS.Leave();
@@ -273,6 +275,9 @@ void Riff_Base::Modify (int32u Chunk_Name_1, int32u Chunk_Name_2, int32u Chunk_N
 //---------------------------------------------------------------------------
 void Riff_Base::Modify_Internal_Subs (int32u Chunk_Name_1, int32u Chunk_Name_2, int32u Chunk_Name_3)
 {
+    if (Chunk.Content.IsRemovable)
+        return;
+
    //Special case: multiples chunks
    if (Global->adtl && (Chunk_Name_1==Elements::WAVE_adtl_labl
                      || Chunk_Name_1==Elements::WAVE_adtl_note
