@@ -376,7 +376,8 @@ public:
         #endif
         Ztring              File_Name;
         int64u              File_Size;
-        string              File_Date;
+        string              File_Date_Created;
+        string              File_Date_Modified;
         string              UnsupportedChunks;
         ostringstream       TruncatedChunks;
         ostringstream       Trace;
@@ -559,7 +560,7 @@ protected :
     //---------------------------------------------------------------------------
     //Read/Write
     virtual void    Read_Internal       ();
-    virtual void    Modify_Internal     ()                                      {}
+    virtual void    Modify_Internal     ()                                      {};
     virtual size_t  Insert_Internal     (int32u)                                {return Subs.size();}
     virtual void    Write_Internal      ()                                      ;
     void            Write_Internal      (const int8u* Buffer, size_t Buffer_Size);
